@@ -1,4 +1,7 @@
+package PerlIO::flock;
+use strict;
 require PerlIO::Util;
+1;
 __END__
 
 =encoding utf-8
@@ -7,6 +10,10 @@ __END__
 
 PerlIO::flock - Easy flock() interface
 
+=for test_synopsis
+
+	my($file, $fh);
+
 =head1 SYNOPSIS
 
 	open my $in,  '< :flock', $file; # shared lock
@@ -24,7 +31,7 @@ That is, if a file is opened for writing, C<:flock> attempts exclusive lock
 (using LOCK_EX). Otherwise, it attempts shared lock (using LOCK_SH).
 
 It waits until the lock is granted. If an argument C<non-blocking> (or
-C<LOCK_NB>) is suplied, the call of C<open()> (or C<binmode()>) fails when
+C<LOCK_NB>) is supplied, the call of C<open()> (or C<binmode()>) fails when
 the lock cannot be granted.
 
 This is a pseudo layer that doesn't be pushed on the layer stack.
